@@ -636,9 +636,7 @@ class Model(H5HintedExport):
             else:
                 prev_columns_list = None
                 prev_columns = {}
-            if prev_columns_list:
-                column_names = prev_columns_list[:3]
-            elif hasattr(self.script_module, 'inst') and self.script_module.inst.coords in ['tth', '2θ']:
+            if hasattr(self.script_module, 'inst') and self.script_module.inst.coords in ['tth', '2θ']:
                 column_names = [Column('TTh', 'deg'), Column('R'), ErrorColumn('R')]
             else:
                 column_names = [Column('Qz', '1/angstrom'), Column('R'), ErrorColumn('R')]
@@ -731,35 +729,21 @@ class Model(H5HintedExport):
         Save the string to file with filename.
         '''
         try:
-            savefile = open(filename, 'w')
+            with open(filename, 'w', encoding='utf-8') as savefile:
+                savefile.write(save_string)
         except Exception as e:
             raise GenxIOError(e.__str__(), filename)
 
-        # Save the string to file
-        try:
-            savefile.write(save_string)
-        except Exception as e:
-            raise GenxIOError(e.__str__(), filename)
-
-        savefile.close()
-
     def _read_from_file(self, filename):
         '''
         Reads the entrie file into string and returns it.
         '''
         try:
-            loadfile = open(filename, 'r')
+            with open(filename, 'r', encoding='utf-8') as loadfile:
+                read_string = loadfile.read()
         except Exception as e:
             raise GenxIOError(e.__str__(), filename)
 
-        # Read the text from file
-        try:
-            read_string = loadfile.read()
-        except Exception as e:
-            raise GenxIOError(e.__str__(), filename)
-
-        loadfile.close()
-
         return read_string
 
     def get_parameters(self) -> Parameters:
